@@ -1,6 +1,7 @@
 import torch
 import transformers
 from transformers import T5Tokenizer, T5EncoderModel, T5Config
+from einops import rearrange
 
 transformers.logging.set_verbosity_error()
 
@@ -52,7 +53,11 @@ def get_encoded_dim(name):
 
 # encoding text
 
-def t5_encode_text(texts, name = DEFAULT_T5_NAME):
+def t5_encode_text(
+    texts,
+    name = DEFAULT_T5_NAME,
+    return_attn_mask = False
+):
     t5, tokenizer = get_model_and_tokenizer(name)
 
     if torch.cuda.is_available():
@@ -77,4 +82,11 @@ def t5_encode_text(texts, name = DEFAULT_T5_NAME):
         output = t5(input_ids = input_ids, attention_mask = attn_mask)
         encoded_text = output.last_hidden_state.detach()
 
-    return encoded_text, attn_mask.bool()
+    attn_mask = attn_mask.bool()
+
+    encoded_text = encoded_text.masked_fill(~rearrange(attn_mask, '... -> ... 1'), 0.) # just force all embeddings that is padding to be equal to 0.
+
+    if return_attn_mask:
+        return encoded_text, attn_mask
+
+    return encoded_text
